==> dokuwiki_0.0.20050922.orig.tar.gz: dokuwiki-2005-09-22/inc/lang/lt/lang.php <==
<?
/**
 * lithuanian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Linas Valiukas <shirshegsm@gmail.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Redaguoti šį puslapį';
$lang['btn_source'] = 'Parodyti puslapio kodą';
$lang['btn_show']   = 'Parodyti puslapį';
$lang['btn_create'] = 'Sukurti šį puslapį';
$lang['btn_search'] = 'Paieška';
$lang['btn_save']   = 'Išsaugoti';
$lang['btn_preview']= 'Peržiūra';
$lang['btn_top']    = 'Į viršų';
$lang['btn_newer']  = '<< naujesnė';
$lang['btn_older']  = 'senesnė >>';
$lang['btn_revs']   = 'Senos versijos';
$lang['btn_recent'] = 'Naujausi keitimai';
$lang['btn_upload'] = 'Atsiųsti bylą';
$lang['btn_cancel'] = 'Atšaukti';
$lang['btn_index']  = 'Indeksas';
$lang['btn_secedit']= 'Redaguoti';
$lang['btn_login']  = 'Prisijungti';
$lang['btn_logout'] = 'Atsijungti';
$lang['btn_admin']  = 'Administracija';
$lang['btn_update'] = 'Atnaujinti';
$lang['btn_delete'] = 'Ištrinti';
$lang['btn_back']   = 'Atgal';
$lang['btn_backtomedia'] = 'Atgal į Mediabylos išsirinkimą';

$lang['loggedinas'] = 'Prisijungęs kaip';
$lang['user']       = 'Vartotojo vardas';
$lang['pass']       = 'Slaptažodis';
$lang['passchk']    = 'dar kartą';
$lang['remember']   = 'Prisiminti mane';
$lang['fullname']   = 'Visas vardas';
$lang['email']      = 'El. pašto adresas';
$lang['register']   = 'Registruotis';
$lang['badlogin']   = 'Nurodėte blogą vartotojo vardą arba slaptažodį.';

$lang['regmissing'] = 'Turite užpildyti visus laukus.';
$lang['reguexists'] = 'Vartotojas su pasirinktu prisijungimo vardu jau egzistuoja.';
$lang['regsuccess'] = 'Vartotojas sukurtas, slaptažodis išsiųstas el. paštu.';
$lang['regsuccess2']= 'Vartotojas sukurtas.';
$lang['regmailfail']= 'Siunčiant slaptažodį el. paštu įvyko klaida - susisiekite su administracija!';
$lang['regbadmail'] = 'Nurodytas el. pašto adresas yra neteisingas - jei manote, kad tai klaida, susisiekite su administracija';
$lang['regbadpass'] = 'Įvesti slaptažodžiai nesutampa, bandykite dar kartą.';
$lang['regpwmail']  = 'Jūsų DokuWiki slaptažodis';
$lang['reghere']    = 'Dar neužsiregistravote? Padarykite tai dabar';

$lang['txt_upload']   = 'Išsirinkite atsiunčiamą bylą';
$lang['txt_filename'] = 'Įveskite wikivardą (nebūtina)';
$lang['txt_overwrt']  = 'Perrašyti egzistuojančią bylą';
$lang['lockedby']     = 'Užrakintas vartotojo';
$lang['lockexpire']   = 'Užraktas bus nuimtas';
$lang['willexpire']   = 'Šio puslapio redagavimo užrakto galiojimo laikas baigsis po minutės.\nNorėdami išvengti nesklandumų naudokite peržiūros mygtuką ir užraktas atsinaujins.';

$lang['notsavedyet'] = 'Pakeitimai nebus išsaugoti.\nTikrai tęsti?';
$lang['rssfailed']   = 'Siunčiant šį feed\'ą įvyko klaida: ';
$lang['nothingfound']= 'Paieškos rezultatų nėra.';

$lang['mediaselect'] = 'Mediabylos išsirinkimas';
$lang['fileupload']  = 'Mediabylos atsiuntimas';
$lang['uploadsucc']  = 'Atsiuntimas pavyko';
$lang['uploadfail']  = 'Atsiuntimas nepavyko. Blogi priėjimo leidimai??';
$lang['uploadwrong'] = 'Atsiuntimas atmestas. Bylos tipas neleistinas';
$lang['uploadexist'] = 'Tokia byla jau egzistuoja. Veiksmai atšaukti.';
$lang['deletesucc']  = 'Byla "%s" ištrinta.';
$lang['deletefail']  = 'Byla "%s" negali būti ištrinta - patikrinkite leidimus.';
$lang['mediainuse']  = 'Byla "%s" nebuvo ištrinta - ji vis dar naudojama.';
$lang['namespaces']  = 'Pavadinimai';
$lang['mediafiles']  = 'Prieinamos bylos';

$lang['reference']   = 'Paminėjimai';
$lang['ref_inuse']   = 'Byla negali būti ištrinta, nes ji vis dar yra naudojama šiuose puslapiuose:';
$lang['ref_hidden']  = 'Kai kurie paminėjimai yra puslapiuose, kurių jums neleista skaityti.';

$lang['hits']       = 'Atidarymai';
$lang['quickhits']  = 'Sutampantys pavadinimai';
$lang['toc']        = 'Turinys';
$lang['current']    = 'esamas';
$lang['yours']      = 'Jūsų versija';
$lang['diff']       = 'rodyti skirtumus tarp šios ir esamos versijos';
$lang['line']       = 'Linija';
$lang['breadcrumb'] = 'Kelias';
$lang['lastmod']    = 'Keista';
$lang['by']         = 'vartotojo';
$lang['deleted']    = 'ištrintas';
$lang['created']    = 'sukurtas';
$lang['restored']   = 'atstatyta sena versija';
$lang['summary']    = 'Redaguoti santrauką';

$lang['mail_newpage'] = '[DokuWiki] puslapis pridėtas:';
$lang['mail_changed'] = '[DokuWiki] puslapis pakeistas:';

$lang['nosmblinks'] = 'Nurodos į "Windows shares" veikia tik su Microsoft Internet Explorer naršykle.\nVis dėlto, jūs galite nukopijuoti šią nuorodą.';

$lang['qb_alert']   = 'Įveskite formatuojamą tekstą.\nJis bus pridėtas dokumento apačioje.';
$lang['qb_bold']    = 'Pusjuodis';
$lang['qb_italic']  = 'Kursyvas';
$lang['qb_underl']  = 'Pabrauktas';
$lang['qb_code']    = 'Kodas';
$lang['qb_strike']  = 'Perbraukta';
$lang['qb_h1']      = 'Pirmo lygio antraštė';
$lang['qb_h2']      = 'Antro lygio antraštė';
$lang['qb_h3']      = 'Trečio lygio antraštė';
$lang['qb_h4']      = 'Ketvirto lygio antraštė';
$lang['qb_h5']      = 'Penkto lygio antraštė';
$lang['qb_link']    = 'Vidinė nuoroda';
$lang['qb_extlink'] = 'Išorinė nuoroda';
$lang['qb_hr']      = 'Horizontali linija';
$lang['qb_ol']      = 'Numeruotas sąrašas';
$lang['qb_ul']      = 'Nenumetuotas sąrašas';
$lang['qb_media']   = 'Paveikslėliai ir kitos bylos';
$lang['qb_sig']     = 'Įterpti parašą';

$lang['del_confirm']= 'Ištrinti šį įrašą?';

$lang['admin_acl']  = 'Priėjimo Kontrolės Sąrašų valdymas...';
$lang['admin_register']= 'Sukurti naują vartotoją...';

$lang['acl_group']  = 'Grupė';
$lang['acl_user']   = 'Vartotojas';
$lang['acl_perms']  = 'Leidimai';
$lang['page']       = 'Puslapis';
$lang['namespace']  = 'Pavadinimas';

$lang['acl_perm1']  = 'Skaityti';
$lang['acl_perm2']  = 'Redaguoti';
$lang['acl_perm4']  = 'Sukurti';
$lang['acl_perm8']  = 'Atsiųsti';
$lang['acl_perm16'] = 'Ištrinti';
$lang['acl_new']    = 'Pridėti naują įrašą';

$lang['spell_start'] = 'Patikrinti rašybą';
$lang['spell_stop']  = 'Tęsti redagavimą';
$lang['spell_wait']  = 'Prašau palaukti...';
$lang['spell_noerr'] = 'Klaidų nerasta';
$lang['spell_nosug'] = 'Taisymo pasiūlymų nėra';
$lang['spell_change']= 'Keisti';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/inc/lang/lt/lang.php <==
<?php
/**
 * lithuanian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Linas Valiukas <shirshegsm@gmail.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Redaguoti šį puslapį';
$lang['btn_source'] = 'Parodyti puslapio kodą';
$lang['btn_show']   = 'Parodyti puslapį';
$lang['btn_create'] = 'Sukurti šį puslapį';
$lang['btn_search'] = 'Paieška';
$lang['btn_save']   = 'Išsaugoti';
$lang['btn_preview']= 'Peržiūra';
$lang['btn_top']    = 'Į viršų';
$lang['btn_newer']  = '<< naujesnė';
$lang['btn_older']  = 'senesnė >>';
$lang['btn_revs']   = 'Senos versijos';
$lang['btn_recent'] = 'Naujausi keitimai';
$lang['btn_upload'] = 'Atsiųsti bylą';
$lang['btn_cancel'] = 'Atšaukti';
$lang['btn_index']  = 'Indeksas';
$lang['btn_secedit']= 'Redaguoti';
$lang['btn_login']  = 'Prisijungti';
$lang['btn_logout'] = 'Atsijungti';
$lang['btn_admin']  = 'Administracija';
$lang['btn_update'] = 'Atnaujinti';
$lang['btn_delete'] = 'Ištrinti';
$lang['btn_back']   = 'Atgal';
$lang['btn_backlink'] = 'Atgalinės nuorodos';
$lang['btn_backtomedia'] = 'Atgal į Mediabylos išsirinkimą';
$lang['btn_subscribe'] = 'Užsisakyti keitimų prenumeratą';
$lang['btn_unsubscribe'] = 'Atsisakyti keitimų prenumeratos';

$lang['loggedinas'] = 'Prisijungęs kaip';
$lang['user']       = 'Vartotojo vardas';
$lang['pass']       = 'Slaptažodis';
$lang['passchk']    = 'dar kartą';
$lang['remember']   = 'Prisiminti mane';
$lang['fullname']   = 'Visas vardas';
$lang['email']      = 'El. pašto adresas';
$lang['register']   = 'Registruotis';
$lang['badlogin']   = 'Nurodėte blogą vartotojo vardą arba slaptažodį.';
$lang['minoredit']  = 'Nedidelis pataisymas';

$lang['regmissing'] = 'Turite užpildyti visus laukus.';
$lang['reguexists'] = 'Vartotojas su pasirinktu prisijungimo vardu jau egzistuoja.';
$lang['regsuccess'] = 'Vartotojas sukurtas, slaptažodis išsiųstas el. paštu.';
$lang['regsuccess2']= 'Vartotojas sukurtas.';
$lang['regmailfail']= 'Siunčiant slaptažodį el. paštu įvyko klaida - susisiekite su administracija!';
$lang['regbadmail'] = 'Nurodytas el. pašto adresas yra neteisingas - jei manote, kad tai klaida, susisiekite su administracija';
$lang['regbadpass'] = 'Įvesti slaptažodžiai nesutampa, bandykite dar kartą.';
$lang['regpwmail']  = 'Jūsų DokuWiki slaptažodis';
$lang['reghere']    = 'Dar neužsiregistravote? Padarykite tai dabar';

$lang['txt_upload']   = 'Išsirinkite atsiunčiamą bylą';
$lang['txt_filename'] = 'Įveskite wikivardą (nebūtina)';
$lang['txt_overwrt']  = 'Perrašyti egzistuojančią bylą';
$lang['lockedby']     = 'Užrakintas vartotojo';
$lang['lockexpire']   = 'Užraktas bus nuimtas';
$lang['willexpire']   = 'Šio puslapio redagavimo užrakto galiojimo laikas baigsis po minutės.\nNorėdami išvengti nesklandumų naudokite peržiūros mygtuką ir užraktas atsinaujins.';

$lang['notsavedyet'] = 'Pakeitimai nebus išsaugoti.\nTikrai tęsti?';
$lang['rssfailed']   = 'Siunčiant šį feed\'ą įvyko klaida: ';
$lang['nothingfound']= 'Paieškos rezultatų nėra.';

$lang['mediaselect'] = 'Mediabylos išsirinkimas';
$lang['fileupload']  = 'Mediabylos atsiuntimas';
$lang['uploadsucc']  = 'Atsiuntimas pavyko';
$lang['uploadfail']  = 'Atsiuntimas nepavyko. Blogi priėjimo leidimai??';
$lang['uploadwrong'] = 'Atsiuntimas atmestas. Bylos tipas neleistinas';
$lang['uploadexist'] = 'Tokia byla jau egzistuoja. Veiksmai atšaukti.';
$lang['deletesucc']  = 'Byla "%s" ištrinta.';
$lang['deletefail']  = 'Byla "%s" negali būti ištrinta - patikrinkite leidimus.';
$lang['mediainuse']  = 'Byla "%s" nebuvo ištrinta - ji vis dar naudojama.';
$lang['namespaces']  = 'Pavadinimai';
$lang['mediafiles']  = 'Prieinamos bylos';

$lang['reference']   = 'Paminėjimai';
$lang['ref_inuse']   = 'Byla negali būti ištrinta, nes ji vis dar yra naudojama šiuose puslapiuose:';
$lang['ref_hidden']  = 'Kai kurie paminėjimai yra puslapiuose, kurių jums neleista skaityti.';

$lang['hits']       = 'Atidarymai';
$lang['quickhits']  = 'Sutampantys pavadinimai';
$lang['toc']        = 'Turinys';
$lang['current']    = 'esamas';
$lang['yours']      = 'Jūsų versija';
$lang['diff']       = 'rodyti skirtumus tarp šios ir esamos versijos';
$lang['line']       = 'Linija';
$lang['breadcrumb'] = 'Kelias';
$lang['lastmod']    = 'Keista';
$lang['by']         = 'vartotojo';
$lang['deleted']    = 'ištrintas';
$lang['created']    = 'sukurtas';
$lang['restored']   = 'atstatyta sena versija';
$lang['summary']    = 'Redaguoti santrauką';

$lang['mail_newpage'] = '[DokuWiki] puslapis pridėtas:';
$lang['mail_changed'] = '[DokuWiki] puslapis pakeistas:';

$lang['nosmblinks'] = 'Nurodos į "Windows shares" veikia tik su Microsoft Internet Explorer naršykle.\nVis dėlto, jūs galite nukopijuoti šią nuorodą.';

$lang['qb_alert']   = 'Įveskite formatuojamą tekstą.\nJis bus pridėtas dokumento apačioje.';
$lang['qb_bold']    = 'Pusjuodis';
$lang['qb_italic']  = 'Kursyvas';
$lang['qb_underl']  = 'Pabrauktas';
$lang['qb_code']    = 'Kodas';
$lang['qb_strike']  = 'Perbraukta';
$lang['qb_h1']      = 'Pirmo lygio antraštė';
$lang['qb_h2']      = 'Antro lygio antraštė';
$lang['qb_h3']      = 'Trečio lygio antraštė';
$lang['qb_h4']      = 'Ketvirto lygio antraštė';
$lang['qb_h5']      = 'Penkto lygio antraštė';
$lang['qb_link']    = 'Vidinė nuoroda';
$lang['qb_extlink'] = 'Išorinė nuoroda';
$lang['qb_hr']      = 'Horizontali linija';
$lang['qb_ol']      = 'Numeruotas sąrašas';
$lang['qb_ul']      = 'Nenumetuotas sąrašas';
$lang['qb_media']   = 'Paveikslėliai ir kitos bylos';
$lang['qb_sig']     = 'Įterpti parašą';

$lang['del_confirm']= 'Ištrinti šį įrašą?';
$lang['admin_register']= 'Sukurti naują vartotoją';

$lang['spell_start'] = 'Patikrinti rašybą';
$lang['spell_stop']  = 'Tęsti redagavimą';
$lang['spell_wait']  = 'Prašau palaukti...';
$lang['spell_noerr'] = 'Klaidų nerasta';
$lang['spell_nosug'] = 'Taisymo pasiūlymų nėra';
$lang['spell_change']= 'Keisti';

$lang['metaedit'] = 'Redaguoti metaduomenis';
$lang['metasaveerr'] = 'Nepavyko išsaugoti metaduomenų';
$lang['metasaveok'] = 'Metaduomenys išsaugoti';
$lang['img_backto'] = 'Atgal į';
$lang['img_title'] = 'Pavadinimas';
$lang['img_caption'] = 'Antraštė';
$lang['img_date'] = 'Data';
$lang['img_fname'] = 'Bylos pavadinimas';
$lang['img_fsize'] = 'Dydis';
$lang['img_artist'] = 'Fotografas';
$lang['img_copyr'] = 'Autorinės teisės';
$lang['img_format'] = 'Formatas';
$lang['img_camera'] = 'Kamera';
$lang['img_keywords'] = 'Raktiniai žodžiai';

$lang['subscribe_success']  = '%s užsakyta "%s" prenumerata';
$lang['subscribe_error']    = '%s užsakant "%s" prenumeratą įvyko klaida';
$lang['subscribe_noaddress']= 'Jūs nesatė nurodęs el. pašto adreso, todėl negalima Jums užsakyti prenumeratos';
$lang['unsubscribe_success']= '%s ištrintas iš "%s" prenumeratos';
$lang['unsubscribe_error']  = '%s trinant iš "%s" prenumeratos įvyko klaida';

//Setup VIM: ex: et ts=2 enc=utf-8 :
